@@ -1,9 +1,9 @@
 package Acme::CPANModules::BrowserUtilities;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-03'; # DATE
+our $DATE = '2021-06-09'; # DATE
 our $DIST = 'Acme-CPANModules-BrowserUtilities'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use Acme::CPANModulesUtil::Misc;
@@ -32,16 +32,15 @@ Install latest Firefox using <prog:instopt> (from <pm:App::instopt>) and
 
 ***Automating Firefox***
 
-TODO: Comparison between these
-
-<pm:WWW::Mechanize::Firefox>, <pm:WWW::Mechanize::Firefox::Extended>.
-
-<pm:Firefox::Application>
-
 <pm:Firefox::Marionette>
 
 <pm:Selenium::Firefox>
 
+<pm:WWW::Mechanize::Firefox> and <pm:MozRepl> used to be an alternative but no
+longer work on current Firefox version (they require Firefox 54 or earlier).
+Included in this group are: <pm:Firefox::Application>,
+<pm:WWW::Mechanize::Firefox::Extended>.
+
 _
 
 our $text_chrome = <<'_';
@@ -123,7 +122,7 @@ Acme::CPANModules::BrowserUtilities - Utilities for web browsers
 
 =head1 VERSION
 
-This document describes version 0.002 of Acme::CPANModules::BrowserUtilities (from Perl distribution Acme-CPANModules-BrowserUtilities), released on 2020-06-03.
+This document describes version 0.003 of Acme::CPANModules::BrowserUtilities (from Perl distribution Acme-CPANModules-BrowserUtilities), released on 2021-06-09.
 
 =head1 DESCRIPTION
 
@@ -150,16 +149,15 @@ L<WordList::HTTP::UserAgentString::Browser::Firefox>
 
 B<I<Automating Firefox>>
 
-TODO: Comparison between these
-
-L<WWW::Mechanize::Firefox>, L<WWW::Mechanize::Firefox::Extended>.
-
-L<Firefox::Application>
-
 L<Firefox::Marionette>
 
 L<Selenium::Firefox>
 
+L<WWW::Mechanize::Firefox> and L<MozRepl> used to be an alternative but no
+longer work on current Firefox version (they require Firefox 54 or earlier).
+Included in this group are: L<Firefox::Application>,
+L<WWW::Mechanize::Firefox::Extended>.
+
 B<Google Chrome>
 
 L<App::ChromeUtils> (comes with CLIs like L<pause-chrome>,
@@ -187,7 +185,7 @@ L<App::DumpVivaldiHistory> (comes with CLI: L<dump-vivaldi-history>).
 
 L<Vivaldi::Util::Profile>
 
-=head1 INCLUDED MODULES
+=head1 ACME::MODULES ENTRIES
 
 =over
 
@@ -207,16 +205,18 @@ L<Vivaldi::Util::Profile>
 
 =item * L<WordList::HTTP::UserAgentString::Browser::Firefox>
 
-=item * L<WWW::Mechanize::Firefox>
-
-=item * L<WWW::Mechanize::Firefox::Extended>
-
-=item * L<Firefox::Application>
-
 =item * L<Firefox::Marionette>
 
 =item * L<Selenium::Firefox>
 
+=item * L<WWW::Mechanize::Firefox>
+
+=item * L<MozRepl>
+
+=item * L<Firefox::Application>
+
+=item * L<WWW::Mechanize::Firefox::Extended>
+
 =item * L<App::ChromeUtils>
 
 =item * L<App::DumpChromeHistory>
@@ -239,10 +239,22 @@ L<Vivaldi::Util::Profile>
 
 =head1 FAQ
 
-=head2 What are ways to use this module?
+=head2 What is an Acme::CPANModules::* module?
 
-Aside from reading it, you can install all the listed modules using
-L<cpanmodules>:
+An Acme::CPANModules::* module, like this module, contains just a list of module
+names that share a common characteristics. It is a way to categorize modules and
+document CPAN. See L<Acme::CPANModules> for more details.
+
+=head2 What are ways to use this Acme::CPANModules module?
+
+Aside from reading this Acme::CPANModules module's POD documentation, you can
+install all the listed modules (entries) using L<cpanm-cpanmodules> script (from
+L<App::cpanm::cpanmodules> distribution):
+
+ % cpanm-cpanmodules -n BrowserUtilities
+
+Alternatively you can use the L<cpanmodules> CLI (from L<App::cpanmodules>
+distribution):
 
     % cpanmodules ls-entries BrowserUtilities | cpanm -n
 
@@ -250,9 +262,13 @@ or L<Acme::CM::Get>:
 
     % perl -MAcme::CM::Get=BrowserUtilities -E'say $_->{module} for @{ $LIST->{entries} }' | cpanm -n
 
-This module also helps L<lcpan> produce a more meaningful result for C<lcpan
-related-mods> when it comes to finding related modules for the modules listed
-in this Acme::CPANModules module.
+or directly:
+
+    % perl -MAcme::CPANModules::BrowserUtilities -E'say $_->{module} for @{ $Acme::CPANModules::BrowserUtilities::LIST->{entries} }' | cpanm -n
+
+This Acme::CPANModules module also helps L<lcpan> produce a more meaningful
+result for C<lcpan related-mods> command when it comes to finding related
+modules for the modules listed in this Acme::CPANModules module.
 
 =head1 HOMEPAGE
 
@@ -282,7 +298,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
